@@ -12,7 +12,7 @@
 ##################################################################
 
 Version = '2.4'
-Build = '7'
+Build = '8'
 
 import sys
 import os
@@ -66,15 +66,12 @@ class clevenMainWindow(QtGui.QMainWindow):
        QtGui.QWidget.__init__(self, parent)
        self.ui = Ui_clevenMainUI()
        self.ui.setupUi(self)
-       self.setWindowTitle('Cleven %s-%s' % (Version, Build))
+       self.setWindowTitle('Cleven')
        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
-
-       ##Connect Menu Buttons 
-       QtCore.QObject.connect(self.ui.actionQuit,                    QtCore.SIGNAL('triggered()'), QtGui.qApp, QtCore.SLOT('quit()'))
-       QtCore.QObject.connect(self.ui.actionAbout,                   QtCore.SIGNAL('triggered()'), self.showAboutWindow)
        
        ##Connect Push Buttons
+       QtCore.QObject.connect(self.ui.pushButtonAbout,               QtCore.SIGNAL('clicked()'), self.showAboutWindow)
        QtCore.QObject.connect(self.ui.pushButtonConfigureDrivers,    QtCore.SIGNAL('clicked()'), self.showConfigureDriversDialog)
        QtCore.QObject.connect(self.ui.pushButtonDecryptCaptured,     QtCore.SIGNAL('clicked()'), self.showDecryptWindow)
        QtCore.QObject.connect(self.ui.pushButtonShowKeys,            QtCore.SIGNAL('clicked()'), self.showKeysWindow)
@@ -206,9 +203,10 @@ class clevenCapture(QtGui.QMainWindow):
           rValues = filter(None, rValues)                   ##remove unknown (empty)
           for i in rValues:                                 ##iterate on the values stored in the list
              newList = i.split()                            ##split each line into a list
-             newValue = newList[4]                          ##keep the 5th element only
+             print 'The WPS AP is:\n',newList
+             newValue = newList[5]                          ##keep the 5th element only
              values.append(newValue)                        ##append the AP into a new list
-          # print 'The WPS clean list is:\n',values
+          print 'The WPS clean list is:\n',values
        else:
           values = os.popen('sudo %s/%s readESSIDs %s %s' %(pathMain, helperScript, pathStorage, encryption)).read()
           values = values.lstrip(" ")                       ##remove trailing space from first ESSID
@@ -338,8 +336,8 @@ class clevenCapture(QtGui.QMainWindow):
     def executeReaver(self):
        '''Opens an xterm window that sends authentication packets.'''
        
-       # print "reaver -i wlan0 -b ",bssid," -c ",channel," -e ",essid," -a -E -vv" 
-       os.system('osso-xterm -e "sudo %s/%s reaver %s %s" &' % (pathMain, helperScript, bssid, essid))
+       # print "reaver -i wlan0 -b ",bssid," -c ",channel," -a -E -S -vv" 
+       os.system('osso-xterm -e "sudo %s/%s reaver %s" &' % (pathMain, helperScript, bssid))
        
 class clevenConfigureDrivers(QtGui.QDialog):
 
@@ -561,11 +559,12 @@ class clevenManageCaptured(QtGui.QMainWindow):
        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
        
        ##Decryption and Deletion actions
-       QtCore.QObject.connect(self.ui.performActionButton, QtCore.SIGNAL('clicked()'), self.actOnCapturedFiles)
-       QtCore.QObject.connect(self.ui.dictionaryButton, QtCore.SIGNAL('clicked()'), self.showSelectDictionaryDialog)
-       QtCore.QObject.connect(self.ui.capturedList, QtCore.SIGNAL('itemSelectionChanged()'), self.enableActionButtons)
-       QtCore.QObject.connect(self.ui.wepRadio, QtCore.SIGNAL('clicked()'), self.showCapturedFiles)
-       QtCore.QObject.connect(self.ui.wpaRadio, QtCore.SIGNAL('clicked()'), self.showCapturedFiles)
+       QtCore.QObject.connect(self.ui.performActionButton,  QtCore.SIGNAL('clicked()'),               self.actOnCapturedFiles)
+       QtCore.QObject.connect(self.ui.dictionaryButton,     QtCore.SIGNAL('clicked()'),               self.showSelectDictionaryDialog)
+       QtCore.QObject.connect(self.ui.capturedList,         QtCore.SIGNAL('itemSelectionChanged()'),  self.enableActionButtons)
+       QtCore.QObject.connect(self.ui.wepRadio,             QtCore.SIGNAL('clicked()'),               self.showCapturedFiles)
+       QtCore.QObject.connect(self.ui.wpaRadio,             QtCore.SIGNAL('clicked()'),               self.showCapturedFiles)
+       QtCore.QObject.connect(self.ui.arpFiles,          QtCore.SIGNAL('clicked()'),               self.showCapturedFiles)
        
        self.show()       
 
@@ -600,6 +599,7 @@ class clevenManageCaptured(QtGui.QMainWindow):
           self.ui.performActionButton.setEnabled(False)
           self.ui.performActionButton.setText('Delete')       
           self.ui.selectCommonRadio.setEnabled(False)
+          self.ui.arpFiles.setHidden(False)
           
           ##Hide the dictionary selection buttons 
           self.ui.dictionaryButton.setHidden(True)
@@ -612,29 +612,42 @@ class clevenManageCaptured(QtGui.QMainWindow):
           self.ui.performActionButton.setEnabled(False)
           self.ui.performActionButton.setText('Decrypt')
           self.ui.selectCommonRadio.setEnabled(False)
+          self.ui.arpFiles.setHidden(True)
        
     def showCapturedFiles(self):
        '''Read and add in the UI the captured file list'''
-      
-       if self.ui.wepRadio.isChecked():
-          encryption = "WEP"
-          self.ui.dictionaryButton.setHidden(True)
-          self.ui.dictionaryLine.setHidden(True)
+
+       if self.ui.arpFiles.isChecked():
           
+          clist = os.listdir('/home/user')
+       
        else:
-          encryption = "WPA"
-          if deleteModeOn == 'False':
-            self.ui.dictionaryButton.setHidden(False)
-            self.ui.dictionaryLine.setHidden(False)
+          if self.ui.wepRadio.isChecked():
+             encryption = "WEP"
+             self.ui.dictionaryButton.setHidden(True)
+             self.ui.dictionaryLine.setHidden(True)
+             
+          else:
+             encryption = "WPA"
+             if deleteModeOn == 'False':
+               self.ui.dictionaryButton.setHidden(False)
+               self.ui.dictionaryLine.setHidden(False)
+
+          clist = os.listdir(pathStorage + '/' + folderCapturedData + '/' + encryption)
+       
+       clist_clean = [line for line in clist if (('.cap' in line) or ('.ivs' in line))]  
+       clist_clean.sort(key=str.lower)
 
        self.ui.capturedList.clear() 
        self.ui.performActionButton.setEnabled(False)
-       
-       clist = os.listdir(pathStorage + '/' + folderCapturedData + '/' + encryption)
-       clist_clean = [line for line in clist if (('.cap' in line) or ('.ivs' in line))]
-       clist_clean.sort(key=str.lower)
+
        self.ui.capturedList.addItems(clist_clean)
 
+       # print 'replay: ', self.ui.arpFiles.isChecked(), 'wepRadio: ', self.ui.wepRadio.isChecked(), 'wpaRadio: ', self.ui.wpaRadio.isChecked()
+       # print 'the list found:\n', clist
+       # print 'the list clean:\n', clist_clean
+       
+
     def actOnCapturedFiles(self):
        '''Start the decryption OR deletion of the captured files saved in the system'''
 
@@ -687,7 +700,11 @@ class clevenManageCaptured(QtGui.QMainWindow):
              cap = self.capfile.strip().replace('.cap','').replace('.ivs','')
           print "delete cap: ", cap
 
-          os.system('sudo %s/%s deleteCaptured %s %s %s' % (pathMain, helperScript, pathStorage, encryption, cap))
+          if self.ui.arpFiles.isChecked():
+             os.system('sudo %s/%s deleteARP %s' % (pathMain, helperScript, cap))             
+          else: 
+             os.system('sudo %s/%s deleteCaptured %s %s %s' % (pathMain, helperScript, pathStorage, encryption, cap))
+             
           self.showCapturedFiles()          
          
 class clevenShowKeys(QtGui.QMainWindow):
@@ -703,35 +720,55 @@ class clevenShowKeys(QtGui.QMainWindow):
        self.show()       
        
        ##Buttons
-       QtCore.QObject.connect(self.ui.keyRefreshButton, QtCore.SIGNAL('clicked()'), self.refreshKeyList)
-       QtCore.QObject.connect(self.ui.keyReadButton, QtCore.SIGNAL('clicked()'), self.readKey)
-       QtCore.QObject.connect(self.ui.keyList, QtCore.SIGNAL('itemSelectionChanged()'), self.enableReadKeyButton)
-       self.ui.keyReadButton.setEnabled(False)
+       QtCore.QObject.connect(self.ui.keyCopyButton,     QtCore.SIGNAL('clicked()'), self.copyKey)
+       QtCore.QObject.connect(self.ui.keyDelButton,      QtCore.SIGNAL('clicked()'), self.delKey)
+       QtCore.QObject.connect(self.ui.keyList,           QtCore.SIGNAL('itemSelectionChanged()'), self.readKey)
 
-    def enableReadKeyButton(self):
-    
-       self.ui.keyReadButton.setEnabled(True)
-       self.ui.keyBrowser.setText("Please select one of the Key files..")
+
+       self.ui.keyCopyButton.setEnabled(False)
+       self.ui.keyDelButton.setEnabled(False)
+       self.refreshKeyList()
 
     def refreshKeyList(self): 
     
        list = os.listdir(pathStorage + '/' + folderKeys)
        self.ui.keyList.clear()
        self.ui.keyList.addItems(list)
-       self.ui.keyBrowser.setText("Please select one of the Key files..")
+       self.ui.keyBrowser.setText("Select one of the Key files..")
        
     def readKey(self):
     
        if self.ui.keyList.currentRow() == -1:
-          self.ui.keyBrowser.setText("Please select one of the Key files..")
+          self.ui.keyBrowser.setText("Select one of the Key files..")
           return
-       keyfile = str(self.ui.keyList.currentItem().text()).strip()
+       keyFile = str(self.ui.keyList.currentItem().text()).strip()
        try:
-          key = open(pathStorage + '/' + folderKeys + '/' + keyfile, 'r' ).readline()
+          key = open(pathStorage + '/' + folderKeys + '/' + keyFile, 'r' ).readline()
           self.ui.keyBrowser.setText(key)
+          ##enable buttons 
+          self.ui.keyCopyButton.setEnabled(True)
+          self.ui.keyDelButton.setEnabled(True)
+
        except IOError:
           self.ui.keyBrowser.setText("Key file cannot be read..")
 
+    def copyKey(self):
+       self.ui.keyBrowser.selectAll() 
+       self.ui.keyBrowser.copy()
+       
+       message ='Key has been copied to the clipboard..'
+       showQuickMessage(message)
+
+    def delKey(self):
+
+       keyFile = str(self.ui.keyList.currentItem().text()).strip()    
+       os.system('sudo %s/%s deleteKey %s %s' % (pathMain, helperScript, pathStorage, keyFile))
+
+       message ='Key has been deleted from the system..'
+       showQuickMessage(message)
+       
+       self.refreshKeyList()
+  
 class clevenAbout(QtGui.QMainWindow):
     '''About Window'''
       
@@ -764,11 +801,12 @@ class clevenAbout(QtGui.QMainWindow):
        aboutLayout.addWidget(aboutIcon)
        
        aboutLabel = QLabel('''<center><b>Cleven</b><br>version: %s-%s 
-       <br><br><b>Cleven is a user interface to the AirCrack-NG console application.</b> 
+       <br><br><b>Cleven is a user interface to Aircrack-NG and Reaver console applications.</b> 
        <br><br>Licenced under GPLv2
        <br>by <b>Christos Zamantzas</b> (Saturn) 
        <br><br>It provides the ability to easily configure the injection drivers, scan for surrounding stations, and by using injection and authentication or deauthentication, capture Identification Vector keys. 
-       <br><br>In addition, it provides interfaces to decrypt the captured files and manage the keys from successful attacks. 
+       <br><br>In addition, it provides interfaces to decrypt the captured files and manage the keys from successful attacks.
+       <br><br>If Reaver and Wash binaries are available, the interface will provide options to check for WPS compliant stations and initiate tests on them.        
        <br><br><b>DISCLAIMER:</b> 
        <br>The application provided is to be used for educational purposes only. The application creator is in no way responsible for any misuse of the information provided. All of the information in this application is meant to help develop a hacker defence attitude in order to prevent the attacks discussed. In no way should you use the information to cause any kind of damage directly or indirectly. The word "Hack" or "Hacking" should be regarded as "Ethical Hack" or "Ethical Hacking" respectively. You implement the information given at your own risk. 
        <br><br>Additional information on the usage, settings and implications can be found in the wiki pages (see buttons in the end). 
